# creasepattern

Convert `.cp` files to `.png`

Size of the output image is based on the sizes given in the `.cp` file.

## Usage

```python
from creasepattern import cp2png

cp2png('file.cp', 'file.png')
```

## Roadmap

* (Must) Make size of output configurable
* (Must) Make edge types configurable
* (Could) Support more filetypes